name: Pyonir Demo app
theme_name: pencil
description: my site description 
author: Pablo Pycasso
email: info@derryspann.com
timezone: US/Eastern
keywords:- cms, blog, web developers, web designers
enabled_plugins:- pycasso_store
===
Default site configurations